@@ -1,155 +1,6 @@
-package Yars;
-
-use strict;
-use warnings;
-use v5.10.1;
-use Mojo::Base 'Clustericious::App';
-use Yars::Routes;
-use Yars::Tools;
-use Mojo::ByteStream qw/b/;
-use File::Path qw/mkpath/;
-use Log::Log4perl qw(:easy);
-use Number::Bytes::Human qw( format_bytes parse_bytes );
-
-# ABSTRACT: Yet Another RESTful-Archive Service
-our $VERSION = '0.97_01'; # VERSION
-
-
-has secret => rand;
-
-
-sub startup {
-    my $self = shift;
-
-    $self->hook(before_dispatch => sub {
-        my($c) = @_;
-        my $stream = Mojo::IOLoop->stream($c->tx->connection);
-        return unless defined $stream;
-        $stream->timeout(3000);
-    });
-
-    my $max_size = 53687091200;
-
-    my $tools;
-
-    $self->hook(
-        after_build_tx => sub {
-            my ( $tx, $app ) = @_;
-            $tx->req->max_message_size($max_size);
-            $tx->req->content->on(body => sub {
-                    my $content = shift;
-                    my $md5_b64 = $content->headers->header('Content-MD5') or return;
-                    my $md5 = unpack 'H*', b($md5_b64)->b64_decode;
-                    my $disk = $tools->disk_for($md5) or return;
-                    my $tmpdir = join '/', $disk, 'tmp';
-                    -d $tmpdir or do { mkpath $tmpdir;  chmod 0777, $tmpdir; };
-                    -w $tmpdir or chmod 0777, $tmpdir;
-                    $content->asset->on(
-                        upgrade => sub {
-                            my ( $mem, $file ) = @_;
-                            $file->tmpdir($tmpdir);
-                        }
-                    );
-                }
-            );
-        }
-    );
-    
-    $self->SUPER::startup(@_);
-    
-    $tools = Yars::Tools->new($self->config);
-
-    $self->hook(
-        before_dispatch => sub {
-            $tools->refresh_config($self->config);
-        }
-    );
-
-    $self->helper( tools => sub { $tools } );
-
-    if(my $time = $self->config->{test_expiration}) {
-        require Clustericious::Command::stop;
-        WARN "this process will stop after $time seconds";
-        Mojo::IOLoop->timer($time => sub { 
-            WARN "self terminating after $time seconds";
-            eval { Clustericious::Command::stop->run };
-            WARN "error in stop: $@" if $@;
-        });
-    }
-    
-    $max_size = parse_bytes($self->config->max_message_size_server(default => 53687091200));
-    INFO "max message size = " . format_bytes($max_size) . " ($max_size)";
-}
-
-sub sanity_check
-{
-    my($self) = @_;
-
-    return 0 unless $self->SUPER::sanity_check;
-
-    my $sane = 1;
-    
-    my($url) = grep { $_ eq $self->config->url } map { $_->{url} } @{ $self->config->{servers} };
-    
-    unless(defined $url)
-    {
-        say "url for this server is not in the disk map";
-        $sane = 0;
-    }
-    
-    $sane;
-}
-
-sub generate_config {
-    my $self = shift;
-
-    my $root = $ENV{CLUSTERICIOUS_CONF_DIR} || $ENV{HOME};
-
-    return {
-     dirs => [
-         [qw(etc)],
-         [qw(var log)],
-         [qw(var run)],
-         [qw(var lib yars data)],
-     ],
-     files => { 'Yars.conf' => <<'CONF', 'log4perl.conf' => <<CONF2 } };
----
-% my $root = $ENV{HOME};
-start_mode : 'hypnotoad'
-url : http://localhost:9999
-hypnotoad :
-  pid_file : <%= $root %>/var/run/yars.pid
-  listen :
-     - http://localhost:9999
-servers :
-- url : http://localhost:9999
-  disks :
-    - root : <%= $root %>/var/lib/yars/data
-      buckets : [ <%= join ',', '0'..'9', 'a' .. 'f' %> ]
-CONF
-log4perl.rootLogger=TRACE, LOGFILE
-log4perl.logger.Mojolicious=TRACE
-log4perl.appender.LOGFILE=Log::Log4perl::Appender::File
-log4perl.appender.LOGFILE.filename=$root/var/log/yars.log
-log4perl.appender.LOGFILE.mode=append
-log4perl.appender.LOGFILE.layout=PatternLayout
-log4perl.appender.LOGFILE.layout.ConversionPattern=[%d{ISO8601}] [%7Z] %5p: %m%n
-CONF2
-}
-
-
-1;
-
-__END__
-=pod
-
 =head1 NAME
 
-Yars - Yet Another RESTful-Archive Service
-
-=head1 VERSION
-
-version 0.97_01
+Yars -- Yet Another RESTful-Archive Service
 
 =head1 DESCRIPTION
 
@@ -297,32 +148,71 @@ L<Yars> is the application package, it inherits from
 L<Clustericious::App> and overrides the following
 methods :
 
+=cut
+
+package Yars;
+
+use strict;
+use warnings;
+use Mojo::Base 'Clustericious::App';
+use Yars::Routes;
+use Yars::Tools;
+use Mojo::ByteStream qw/b/;
+use File::Path qw/mkpath/;
+our $VERSION = '0.74';
+
+has secret => rand;
+
 =head2 startup
 
 Called by the server to start up, we change
 the object classes to use Yars::Message::Request
 for incoming requests.
 
+=cut
+
+sub startup {
+    my $self = shift;
+    if ($Mojolicious::VERSION >= 2.37) {
+        Mojo::IOLoop::Stream->timeout(3000);
+    } else {
+        Mojo::IOLoop->singleton->connection_timeout(3000);
+    }
+    $self->hook(
+        after_build_tx => sub {
+            my ( $tx, $app ) = @_;
+            $tx->req->content->on(body => sub {
+                    my $content = shift;
+                    my $md5_b64 = $content->headers->header('Content-MD5') or return;
+                    my $md5 = unpack 'H*', b($md5_b64)->b64_decode;
+                    my $disk = Yars::Tools->disk_for($md5) or return;
+                    my $tmpdir = join '/', $disk, 'tmp';
+                    -d $tmpdir or do { mkpath $tmpdir;  chmod 0777, $tmpdir; };
+                    -w $tmpdir or chmod 0777, $tmpdir;
+                    $content->asset->on(
+                        upgrade => sub {
+                            my ( $mem, $file ) = @_;
+                            $file->tmpdir($tmpdir);
+                        }
+                    );
+                }
+            );
+        }
+    );
+    $self->SUPER::startup(@_);
+}
+
+=head1 AUTHORS
+
+ Marty Brandon
+
+ Brian Duggan
+
 =head1 SEE ALSO
 
 L<Yars::Client>
 
-=head1 AUTHOR
-
-original author: Marty Brandon
-
-current maintainer: Graham Ollis <plicease@cpan.org>
-
-contributors:
-
-Brian Duggan
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2013 by NASA GSFC.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
 
+
+1;
